@@ -5,6 +5,8 @@ Unit tests.
 import os
 import unittest
 
+import numpy as np
+
 import opennsfw2 as n2
 
 BASE_DIR = os.path.dirname(os.path.abspath(__file__))
@@ -18,20 +20,20 @@ IMAGE_PATHS = [
 
 class TestModel(unittest.TestCase):
 
+    def _assert(self, expected: np.ndarray, predicted: np.ndarray) -> None:
+        for expected_score, predicted_score in zip(expected, predicted):
+            self.assertAlmostEqual(expected_score, predicted_score, places=3)
+
     def test_inference_yahoo_preprocessing(self) -> None:
-        expected_scores = [0.012, 0.756, 0.067]
-        predictions = n2.predict(
+        expected_scores = np.array([0.012, 0.756, 0.067])
+        predicted_scores = n2.predict(
             IMAGE_PATHS, preprocessing=n2.Preprocessing.YAHOO
-        )
-        for expected_score, prediction in zip(expected_scores, predictions):
-            score = prediction[1]
-            self.assertAlmostEqual(expected_score, score, places=3)
+        )[:, 1]
+        self._assert(expected_scores, predicted_scores)
 
     def test_inference_simple_preprocessing(self) -> None:
-        expected_scores = [0.001, 0.597, 0.003]
-        predictions = n2.predict(
+        expected_scores = np.array([0.001, 0.597, 0.003])
+        predicted_scores = n2.predict(
             IMAGE_PATHS, preprocessing=n2.Preprocessing.SIMPLE
-        )
-        for expected_score, prediction in zip(expected_scores, predictions):
-            score = prediction[1]
-            self.assertAlmostEqual(expected_score, score, places=3)
+        )[:, 1]
+        self._assert(expected_scores, predicted_scores)
